@@ -8,6 +8,7 @@ import operator
 import string
 import re
 import datetime
+import time
 import six
 
 from operator import itemgetter
@@ -56,6 +57,19 @@ class TaskProcessor:
     def help(self):
         return 'ZZZ' + self._help
 
+    def fullhelp(self):
+        
+        msg = ""
+        msg += self.code+'\t'+self.help+'\n'
+        if self.parse_args and self.defconf:                    
+            msg += '\tkey-arguments:\n';
+            for aname in sorted(self.defconf):
+                msg += '\t'+aname+'="'+self.defconf[aname]+'"\n'
+        if self.store_argline:
+            msg+='\targument ({}), default: "{}"\n'.format(self.store_argline,self.defconf[self.store_argline])
+        return msg
+        
+
     def __init__(self, code, tsclass):
         self.code = code
         tsclass.addtproc(code,self)
@@ -202,16 +216,7 @@ class TaskSeq():
         # print("created. iname:{}".format(iname))
 
     def initvars(self):
-        today = datetime.date.today()
-        self.v['_day'] = today.day
-        self.v['_month'] = today.month
-        self.v['_year'] = today.year 
-
-        self.v['_dd']="%02d" % today.day
-        self.v['_mm']="%02d" % today.month
-        self.v['_yy']="%02d" % (today.year % 100 )
-
-
+        pass
   
 
     #
@@ -264,14 +269,7 @@ class TaskSeq():
         def helpchapter(chapters,chapter):
             msg='  '+chapter+'\n  ---\n'
             for c in sorted(chapters[chapter],key=operator.attrgetter('code')):
-                msg+=c.code+'\t'+c.help+'\n'
-                if c.parse_args and c.defconf:                    
-                    msg+='\tkey-arguments:\n'
-                    for aname in sorted(c.defconf):
-                        msg+='\t'+aname+'="'+c.defconf[aname]+'"\n'
-                if c.store_argline:
-                    msg+='\targument ({}), default: "{}"\n'.format(c.store_argline,c.defconf[c.store_argline])
-                
+                msg+=c.fullhelp()
             msg+='\n'
             return msg
 
@@ -325,11 +323,13 @@ class TaskSeq():
             
             if isinstance(data,six.string_types):
                 vv['_str'] = data
-                
-            
+                           
             # replace vars
             for argname,argval in r.items():
+                #print("replace arg {} = {}".format(argname, argval))
+                #print(vv)
                 newval = string.Template(argval).safe_substitute(vv)
+                #print("newval: {}".format(newval))
                 r[argname] = newval
 
             
@@ -472,8 +472,12 @@ class TaskName(GenTaskProcessor):
 
     defconf = {'name': '$_name:noname'}
     def run(self,ts,data,args):
-        vv = ts.getvars()                
-        ts.iname = string.Template(args['name']).substitute(vv)
+        #vv = ts.getvars()
+        #if isinstance(data,dict):
+        #    vv.update(data) 
+        #ts.oc.log.debug("NAME: {}".format(args['name']))                
+        #ts.iname = string.Template(args['name']).safe_substitute(vv)
+        ts.iname = args['name']
         
         return data
 
@@ -572,7 +576,7 @@ class TaskSort(GenTaskProcessor):
             
         if self.argbool(args,'num'):
             try:
-                data = sorted(data, key=int)        
+                data = sorted(data, key=float)        
             except ValueError:
                 pass
         else:
@@ -610,7 +614,7 @@ class TaskSeqDump(GenTaskProcessor):
         print("details:",ts.details)
         print("method:",ts.method)
         print("tags:",ts.tags)
-#        print("variables:",json.dumps(ts.v, sort_keys=True, indent=4, separators=(',',': ')))
+        print("variables:",json.dumps(ts.v, sort_keys=True, indent=4, separators=(',',': ')))
         if data is None:
             print("no data")
         else:
@@ -662,7 +666,7 @@ class TaskMkSeq(GenTaskProcessor):
         
     def mkroute(self,ts,data):
         route = list()
-        for k in sorted(data):
+        for k in sorted(data, key=int):
             e = data[k]
             #etpl = string.Template(e)            
             #e = etpl.safe_substitute(v)            
@@ -742,6 +746,45 @@ class TaskMkSeq(GenTaskProcessor):
 TaskMkSeq('MKSEQ', TaskSeq)
 
 
+class TaskDateTime(GenTaskProcessor):
+    help = 'Set date and time variables'
+
+    defconf = {
+        'prefix': '_',
+        'offset': '0'
+    }
+
+    def run(self,ts,data,args):               
+        moment = time.time()
+        moment += int(args['offset'])
+        m = datetime.datetime.fromtimestamp(moment)
+        
+        
+        prefix = args['prefix']
+        ts.setvar(prefix+'day', m.day)
+        ts.setvar(prefix+'month', m.month)
+        ts.setvar(prefix+'year', m.year) 
+
+        ts.setvar(prefix+'dd',"%02d" % m.day)
+        ts.setvar(prefix+'mm',"%02d" % m.month)
+        ts.setvar(prefix+'yy',"%02d" % (m.year % 100 ))
+
+        ts.setvar(prefix+'hour', m.hour)
+        ts.setvar(prefix+'minute', m.minute)
+        ts.setvar(prefix+'second', m.second) 
+
+        ts.setvar(prefix+'HH',"%02d" % m.hour)
+        ts.setvar(prefix+'MM',"%02d" % m.minute)
+        ts.setvar(prefix+'SS',"%02d" % m.second)
+
+
+        return data
+
+TaskDateTime('DATETIME', TaskSeq)
+
+
+
+
 class TaskKeyVal(GenTaskProcessor):
     help = 'Retrieve data from okerr key-val database'
 
